==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DatePickerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedValueChangedEventArgsDescriptionMetadata } from "./SelectedValueChangedEventArgsDescriptionMetadata";
import { GotFocusEventArgsDescriptionMetadata } from "./GotFocusEventArgsDescriptionMetadata";
import { LostFocusEventArgsDescriptionMetadata } from "./LostFocusEventArgsDescriptionMetadata";
import { KeyEventArgsDescriptionMetadata } from "./KeyEventArgsDescriptionMetadata";
import { InputChangeEventArgsDescriptionMetadata } from "./InputChangeEventArgsDescriptionMetadata";
import { DatePickerDescription } from "./DatePickerDescription";
/**
 * @hidden
 */
var DatePickerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DatePickerDescriptionMetadata, _super);
    function DatePickerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DatePickerDescriptionMetadata.b = function (a) {
        if (DatePickerDescriptionMetadata.a == null) {
            DatePickerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DatePickerDescriptionMetadata.c(DatePickerDescriptionMetadata.a);
        }
        if (a.g(DatePickerDescriptionMetadata.a)) {
            return;
        }
        a.s(DatePickerDescriptionMetadata.a);
        SelectedValueChangedEventArgsDescriptionMetadata.d(a);
        GotFocusEventArgsDescriptionMetadata.d(a);
        LostFocusEventArgsDescriptionMetadata.d(a);
        KeyEventArgsDescriptionMetadata.d(a);
        InputChangeEventArgsDescriptionMetadata.d(a);
    };
    DatePickerDescriptionMetadata.c = function (a) {
        a.item("Value", "Date");
        a.item("Today", "Date");
        a.item("Label", "String");
        a.item("LabelTextColor", "Brush");
        a.item("LabelFontFamily", "(w:LabelFontFamily/FontFamilyTransform,xam:LabelFontFamily,wf:LabelFontFamily,web:labelTextStyle/FontFamilyTransform)String");
        a.item("LabelFontSize", "(w:LabelFontSize,xam:LabelFontSize,wf:LabelFontSize,web:labelTextStyle/FontSizeTransform)Number:double");
        a.item("LabelFontStyle", "(w:LabelFontStyle/FontStyleTransform,xam:LabelFontFamily/FontStyleTransform,wf:LabelFontFamily/FontStyleTransform,web:labelTextStyle/FontStyleTransform)String");
        a.item("LabelFontWeight", "(w:LabelFontWeight/FontWeightTransform,xam:LabelFontFamily/FontWeightTransform,wf:LabelFontFamily/FontWeightTransform,web:labelTextStyle/FontWeightTransform)String");
        a.item("Placeholder", "String");
        a.item("MinDate", "Date");
        a.item("MaxDate", "Date");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("TextFontFamily", "(w:TextFontFamily/FontFamilyTransform,xam:TextFontFamily,wf:TextFontFamily,web:textStyle/FontFamilyTransform)String");
        a.item("TextFontSize", "(w:TextFontSize,xam:TextFontSize,wf:TextFontSize,web:textStyle/FontSizeTransform)Number:double");
        a.item("TextFontStyle", "(w:TextFontStyle/FontStyleTransform,xam:TextFontFamily/FontStyleTransform,wf:TextFontFamily/FontStyleTransform,web:textStyle/FontStyleTransform)String");
        a.item("TextFontWeight", "(w:TextFontWeight/FontWeightTransform,xam:TextFontFamily/FontWeightTransform,wf:TextFontFamily/FontWeightTransform,web:textStyle/FontWeightTransform)String");
        a.item("TextColor", "Brush");
        a.item("IconColor", "Brush");
        a.item("ShowClearButton", "Boolean");
        a.item("ShowTodayButton", "Boolean");
        a.item("AllowTextInput", "Boolean");
        a.item("OpenOnFocus", "Boolean");
        a.item("FirstDayOfWeek", "ExportedType:string:DayOfWeek");
        a.item("FirstDayOfWeek@names", "Sunday;Monday;Tuesday;Wednesday;Thursday;Friday;Saturday");
        a.item("FirstWeekOfYear", "ExportedType:string:FirstWeek");
        a.item("FirstWeekOfYear@names", "FirstDay;FirstFullWeek;FirstFourDayWeek");
        a.item("ShowWeekNumbers", "Boolean");
        a.item("DateFormat", "ExportedType:string:DateFormats");
        a.item("DateFormat@names", "DateShort;DateLong");
        a.item("FormatString", "String");
        a.item("IsDisabled", "Boolean");
        a.item("SelectedValueChangedRef", "EventRef::selectedValueChanged");
        a.item("GotFocusRef", "EventRef::gotFocus");
        a.item("LostFocusRef", "EventRef::lostFocus");
        a.item("KeyDownRef", "EventRef::keyDown");
        a.item("ChangingRef", "EventRef::changing");
        a.item("ValueChangeRef", "EventRef::valueChange");
    };
    DatePickerDescriptionMetadata.d = function (a) {
        DatePickerDescriptionMetadata.b(a);
        a.u("DatePicker", function () { return new DatePickerDescription(); });
        a.t("DatePicker", DatePickerDescriptionMetadata.a);
    };
    DatePickerDescriptionMetadata.$t = markType(DatePickerDescriptionMetadata, 'DatePickerDescriptionMetadata');
    DatePickerDescriptionMetadata.a = null;
    return DatePickerDescriptionMetadata;
}(Base));
export { DatePickerDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DatePickerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SelectedValueChangedEventArgsDescriptionMetadata } from "./SelectedValueChangedEventArgsDescriptionMetadata";
import { GotFocusEventArgsDescriptionMetadata } from "./GotFocusEventArgsDescriptionMetadata";
import { LostFocusEventArgsDescriptionMetadata } from "./LostFocusEventArgsDescriptionMetadata";
import { KeyEventArgsDescriptionMetadata } from "./KeyEventArgsDescriptionMetadata";
import { InputChangeEventArgsDescriptionMetadata } from "./InputChangeEventArgsDescriptionMetadata";
import { DatePickerDescription } from "./DatePickerDescription";
/**
 * @hidden
 */
var DatePickerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DatePickerDescriptionMetadata, _super);
    function DatePickerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DatePickerDescriptionMetadata.b = function (a) {
        if (DatePickerDescriptionMetadata.a == null) {
            DatePickerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DatePickerDescriptionMetadata.c(DatePickerDescriptionMetadata.a);
        }
        if (a.j(DatePickerDescriptionMetadata.a)) {
            return;
        }
        a.y(DatePickerDescriptionMetadata.a);
        SelectedValueChangedEventArgsDescriptionMetadata.d(a);
        GotFocusEventArgsDescriptionMetadata.d(a);
        LostFocusEventArgsDescriptionMetadata.d(a);
        KeyEventArgsDescriptionMetadata.d(a);
        InputChangeEventArgsDescriptionMetadata.d(a);
    };
    DatePickerDescriptionMetadata.c = function (a) {
        a.item("Value", "Date");
        a.item("Today", "Date");
        a.item("Label", "String");
        a.item("LabelTextColor", "Brush");
        a.item("LabelFontFamily", "(w:LabelFontFamily/FontFamilyTransform,xam:LabelFontFamily,wf:LabelFontFamily,web:labelTextStyle/FontFamilyTransform)String");
        a.item("LabelFontSize", "(w:LabelFontSize,xam:LabelFontSize,wf:LabelFontSize,web:labelTextStyle/FontSizeTransform)Number:double");
        a.item("LabelFontStyle", "(w:LabelFontStyle/FontStyleTransform,xam:LabelFontFamily/FontStyleTransform,wf:LabelFontFamily/FontStyleTransform,web:labelTextStyle/FontStyleTransform)String");
        a.item("LabelFontWeight", "(w:LabelFontWeight/FontWeightTransform,xam:LabelFontFamily/FontWeightTransform,wf:LabelFontFamily/FontWeightTransform,web:labelTextStyle/FontWeightTransform)String");
        a.item("Placeholder", "String");
        a.item("MinDate", "Date");
        a.item("MaxDate", "Date");
        a.item("Density", "ExportedType:string:ControlDisplayDensity");
        a.item("Density@names", "Auto;Comfortable;Cosy;Compact");
        a.item("BaseTheme", "ExportedType:string:BaseControlTheme");
        a.item("BaseTheme@names", "Default;DenaliLight;MaterialLight");
        a.item("TextFontFamily", "(w:TextFontFamily/FontFamilyTransform,xam:TextFontFamily,wf:TextFontFamily,web:textStyle/FontFamilyTransform)String");
        a.item("TextFontSize", "(w:TextFontSize,xam:TextFontSize,wf:TextFontSize,web:textStyle/FontSizeTransform)Number:double");
        a.item("TextFontStyle", "(w:TextFontStyle/FontStyleTransform,xam:TextFontFamily/FontStyleTransform,wf:TextFontFamily/FontStyleTransform,web:textStyle/FontStyleTransform)String");
        a.item("TextFontWeight", "(w:TextFontWeight/FontWeightTransform,xam:TextFontFamily/FontWeightTransform,wf:TextFontFamily/FontWeightTransform,web:textStyle/FontWeightTransform)String");
        a.item("TextColor", "Brush");
        a.item("IconColor", "Brush");
        a.item("ShowClearButton", "Boolean");
        a.item("ShowTodayButton", "Boolean");
        a.item("AllowTextInput", "Boolean");
        a.item("OpenOnFocus", "Boolean");
        a.item("FirstDayOfWeek", "ExportedType:string:DayOfWeek");
        a.item("FirstDayOfWeek@names", "Sunday;Monday;Tuesday;Wednesday;Thursday;Friday;Saturday");
        a.item("FirstWeekOfYear", "ExportedType:string:FirstWeek");
        a.item("FirstWeekOfYear@names", "FirstDay;FirstFullWeek;FirstFourDayWeek");
        a.item("ShowWeekNumbers", "Boolean");
        a.item("DateFormat", "ExportedType:string:DateFormats");
        a.item("DateFormat@names", "DateShort;DateLong");
        a.item("FormatString", "String");
        a.item("IsDisabled", "Boolean");
        a.item("SelectedValueChangedRef", "EventRef::selectedValueChanged");
        a.item("GotFocusRef", "EventRef::gotFocus");
        a.item("LostFocusRef", "EventRef::lostFocus");
        a.item("KeyDownRef", "EventRef::keyDown");
        a.item("ChangingRef", "EventRef::changing");
        a.item("ValueChangeRef", "EventRef::valueChange");
    };
    DatePickerDescriptionMetadata.d = function (a) {
        DatePickerDescriptionMetadata.b(a);
        a.aa("DatePicker", function () { return new DatePickerDescription(); });
        a.z("DatePicker", DatePickerDescriptionMetadata.a);
    };
    DatePickerDescriptionMetadata.$t = markType(DatePickerDescriptionMetadata, 'DatePickerDescriptionMetadata');
    DatePickerDescriptionMetadata.a = null;
    return DatePickerDescriptionMetadata;
}(Base));
export { DatePickerDescriptionMetadata };
